#!/bin/bash
#########################################################################################
# Сервис копирования файлов
#
# Этот скрипт запускается сервисом copyservice, Настройки сервиса находятся в
# confFile. COPY_PERIOD устанавливает период копирования в секундах,
# по-умолчанию 60. Если START_SERVICE установлен в yes, сервис будет запускаться,
# по-умолчанию no.
#
# Копирует файлы из workDir в директорию определяемую следующим образом.
# Некоторый файл находящийся в '[workDir][destination]' будет скопирован в
# '[destination]'.
# Например, если файл находится в '/linuxcash/cash/data/copyservice/tmp/test/filename',
# он будет скопирован в '/tmp/test/filename'.
#
# Логи пишет в logFile.
#########################################################################################

workDir=/linuxcash/cash/data/copyservice
logFile=/linuxcash/logs/current/copyservice.log
confFile=/linuxcash/cash/conf/copyservice.conf

# Логгер
log() {
    echo $(date +"%F %X") - $1 >> $logFile
}

trap "log \"Ошибка сервиса\"" ERR

test -f $confFile && . $confFile
if [ "$START_SERVICE" != "yes" ]
then
    service copyservice stop
    exit 0
fi

[ $COPY_PERIOD ] || COPY_PERIOD=60
log "copyservice запущен"
while true
do
    for src in $(find $workDir -type f); do 
        dest=${src#$workDir}
        destDir=$(dirname $dest)

        log "Копирование файла '$src' в '$dest'"
        [ -d $destDir ] || mkdir -p $destDir
        typeFS=`df -P -T $destDir | tail -n +2 | awk '{print $2}'`
        if [ "$typeFS" != "ext3" -a "$typeFS" != "ext4" ]; then
            if output=$(cp $src $dest 2>&1); then
                log "Копирование файла завершено успешно"
                rm $src
            else
                log "Ошибка копирования '$output'"
            fi
        else
            log "Ошибка копирования. Каталог '$destDir' не является примонтированным"
        fi
    done

    # Удаление пустых директорий
    find $workDir -empty -type d -not -path "$workDir" -delete

    sleep $COPY_PERIOD
done
